@@ -18,16 +18,15 @@ This module provides bases classes for tables management.
 import json
 
 from pyramid.decorator import reify
-from zope.component import queryAdapter, queryMultiAdapter
+from zope.component import queryMultiAdapter
 from zope.interface import implementer
-from zope.location import ILocation
 from zope.schema.fieldproperty import FieldProperty
 
 from pyams_security.security import ProtectedViewObjectMixin
 from pyams_table.column import Column, GetAttrColumn
-from pyams_table.table import Table as BaseTable
+from pyams_table.table import Table as BaseTable, get_weight
 from pyams_template.template import get_view_template
-from pyams_utils.adapter import ContextRequestViewAdapter, adapter_config
+from pyams_utils.adapter import ContextRequestViewAdapter
 from pyams_utils.data import ObjectDataManagerMixin
 from pyams_utils.date import SH_DATE_FORMAT, format_datetime
 from pyams_utils.factory import get_object_factory, is_interface
@@ -35,8 +34,9 @@ from pyams_utils.interfaces import ICacheKeyValue
 from pyams_utils.interfaces.data import IObjectData
 from pyams_utils.list import boolean_iter
 from pyams_utils.url import absolute_url
-from pyams_zmi.interfaces.table import IInnerTable, ITableAdminView, ITableElementEditor, \
-    ITableElementName
+from pyams_zmi.interfaces.table import IInnerTable, IMultipleTableView, ITableAdminView, \
+    ITableElementEditor
+from pyams_zmi.utils import get_object_label
 from pyams_zmi.view import InnerAdminView
 
 
@@ -100,10 +100,26 @@ def get_data_attributes(element):
     data = IObjectData(element, None)
     if data is not None:
         return ' '.join(("data-{}='{}'".format(k, v if isinstance(v, str) else json.dumps(v))
-                         for k, v in data.object_data.items()))
+                         for k, v in data.object_data.items()))  # pylint: disable=no-member
     return ''
 
 
+def get_ordered_data_attributes(source, container, request, target='reorder.json'):
+    """Get object data attributes for ordered table"""
+    source.setdefault('table', {}).update({
+        'data-searching': 'false',
+        'data-info': 'false',
+        'data-paging': 'false',
+        'data-ordering': 'false',
+        'data-row-reorder': '{"update": false}',
+        'data-ams-location': absolute_url(container, request),
+        'data-ams-reorder-url': target
+    })
+    source.setdefault('tr', {}).update({
+        'data-ams-row-value': lambda row, col: get_row_name(row)
+    })
+
+
 class Table(ObjectDataManagerMixin, BaseTable):
     """Extended table class"""
 
@@ -165,22 +181,22 @@ class Table(ObjectDataManagerMixin, BaseTable):
         return klass
 
     def render_table(self):
-        return super(Table, self).render_table() \
+        return super().render_table() \
             .replace('<table', '<table {}'.format(get_attributes(self, 'table', self))) \
             .replace('<table', '<table {}'.format(get_data_attributes(self)))
 
     def render_row(self, row, css_class=None):
         css_class = self.get_selected_row_class(row[0], css_class)
-        return super(Table, self).render_row(row, css_class) \
+        return super().render_row(row, css_class) \
             .replace('<tr', '<tr {}'.format(get_attributes(self, 'tr', row[0][0])))
 
     def render_head_cell(self, column):
-        return super(Table, self).render_head_cell(column) \
+        return super().render_head_cell(column) \
             .replace('<th', '<th {}'.format(get_attributes(self, 'th', column))) \
             .replace('<th', '<th {}'.format(get_data_attributes(column)))
 
     def render_cell(self, item, column, colspan=0):
-        return super(Table, self).render_cell(item, column, colspan) \
+        return super().render_cell(item, column, colspan) \
             .replace('<td', '<td {}'.format(get_attributes(self, 'td', item, column)))
 
 
@@ -224,6 +240,33 @@ class InnerTableAdminView(InnerTableMixin):
     """Inner table admin view"""
 
 
+class MultipleTablesMixin:
+    """Multiple tables mixin view class"""
+
+    table_label = FieldProperty(ITableAdminView['table_label'])
+
+    @reify
+    def tables(self):
+        """Tables getter"""
+        registry = self.request.registry
+        return sorted((table
+                       for name, table in
+                       registry.getAdapters((self.context, self.request, self),  # pylint: disable=no-member
+                                            IInnerTable)),
+                      key=get_weight)
+
+    def update(self):
+        """View update"""
+        super().update()
+        for table in self.tables:
+            table.update()
+
+
+@implementer(IMultipleTableView)
+class MultipleTablesAdminView(MultipleTablesMixin, InnerAdminView):
+    """Multiple tables admin view"""
+
+
 class I18nColumnMixin:
     """Column mixin with I18n header"""
 
@@ -235,10 +278,18 @@ class I18nColumnMixin:
         return self.request.localizer.translate(self.i18n_header)
 
 
-@adapter_config(required=ILocation, provides=ITableElementName)
-def location_element_name(context):
-    """Basic location name factory"""
-    return context.__name__
+class ReorderColumn(Column):
+    """Reorder column"""
+
+    weight = 0
+
+    css_classes = {
+        'th': 'reorder action',
+        'td': 'action'
+    }
+
+    def render_cell(self, item):
+        return '<i class="fas fa-arrows-alt-v"></i>'
 
 
 class NameColumn(I18nColumnMixin, GetAttrColumn):
@@ -248,11 +299,7 @@ class NameColumn(I18nColumnMixin, GetAttrColumn):
     weight = 10
 
     def get_value(self, obj):
-        adapter = queryMultiAdapter((obj, self.request, self.table),
-                                    ITableElementName)
-        if adapter is None:
-            adapter = queryAdapter(obj, ITableElementName)
-        return adapter
+        return get_object_label(obj, self.request, self.table)
 
 
 class IconColumn(Column):
@@ -418,7 +465,7 @@ class DateColumn(GetAttrColumn):
 
     def get_value(self, obj):
         """Date column value getter"""
-        value = super(DateColumn, self).get_value(obj)
+        value = super().get_value(obj)
         if not value:
             return '--'
         return format_datetime(value, self.formatter, self.request)
